#######
Zipnish
#######


A micro-service monitoring tool based on Varnish Cache.

.. image:: https://readthedocs.org/projects/zipnish/badge/?version=latest


* `Documentation <http://zipnish.readthedocs.io/en/latest/?>`_
* `Changelog <http://zipnish.readthedocs.io/en/latest/changes.html>`_
* `Source <https://github.com/varnish/zipnish>`_
